/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.data;

import java.util.HashSet;
import java.util.Observable;

/**
 * Keeps track of running worker threads. Threads need to register themselves
 * and unregister when finished.
 * 
 * @author Thomas Abeel
 * 
 */
public class WorkerManager extends Observable{

	private HashSet<DataSourceWorker> running = new HashSet<DataSourceWorker>();

	
	public synchronized void start(DataSourceWorker ds) {
		running.add(ds);
		setChanged();
		notifyObservers();
	}

	public synchronized void done(DataSourceWorker ds) {
		running.remove(ds);
		setChanged();
		notifyObservers();
	}

	public synchronized  int runningJobs() {
		return running.size();
	}
}
