/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.gui.dialog;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.EventQueue;
import java.awt.Rectangle;

import javax.swing.BorderFactory;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JWindow;
import javax.swing.SwingConstants;
import javax.swing.border.Border;

import net.sf.genomeview.data.Model;
import net.sf.genomeview.gui.StaticUtils;

/**
 * 
 * @author Thomas Abeel
 * 
 */
public class Hider extends JDialog {

	private JLabel floater = new JLabel();

	public Hider(Model model, String text) {
		this(model, text, Color.BLACK);
	}

	public void setText(String text) {
		floater.setText(text);
		repaint();
	}

	public Hider(Model model, String text, Color color) {
		this(model, text, color, model.getGUIManager().getParent().getBounds().width / 5, model.getGUIManager()
				.getParent().getBounds().height / 5);

	}

	public Hider(Model model, String text, Color color, int width, int height) {
		// Rectangle bounds = model.getGUIManager().getParent().getBounds();
		// this.setBounds(bounds);
		super(null, ModalityType.APPLICATION_MODAL);
		setUndecorated(true);
		// this.setAlwaysOnTop(true);
		floater.setPreferredSize(new Dimension(width, height));
		floater.setHorizontalAlignment(SwingConstants.CENTER);
		floater.setVerticalAlignment(SwingConstants.CENTER);
		floater.setAlignmentY(CENTER_ALIGNMENT);
		// this.setLocation(bounds.x + bounds.width / 5 * 2, bounds.y +
		// bounds.height / 5 * 2);
		Color c= new Color(color.getRed(),color.getGreen(),color.getBlue(),50);
//		Color c = new Color(100, 100, 100, 50);
		
		floater.setBackground(c);
		//floater.setOpaque(true);
		floater.setText("<html>" + text + "</html>");
		floater.setForeground(color);
		Border emptyBorder = BorderFactory.createEmptyBorder(5, 5, 5, 5);
		Border colorBorder = BorderFactory.createLineBorder(color);
		floater.setBorder(BorderFactory.createCompoundBorder(colorBorder, emptyBorder));
		add(floater);
		pack();
		StaticUtils.center(model.getGUIManager().getParent(),this);
		final Hider _self=this;
		EventQueue.invokeLater(new Runnable() {

			@Override
			public void run() {
				_self.setVisible(true);

			}
		});

	}

}