/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.gui.information;

import java.io.IOException;
import java.net.URISyntaxException;
import java.net.URLEncoder;

import javax.swing.Icon;

import net.sf.genomeview.core.Icons;
import net.sf.genomeview.gui.StaticUtils;
import be.abeel.net.URIFactory;

/**
 * Class representing a website query.
 * 
 * @author Thomas
 * 
 */
public class Query {

	public static Query ncbiQuery = new Query("Query at NCBI Entrez",
			"http://www.ncbi.nlm.nih.gov/sites/gquery?term=%query%",Icons.NCBI);
	public static Query ensemblQuery = new Query("Query at Ensembl",
			"http://www.ensembl.org/common/Search/Results?species=all;idx=;q=%query%",Icons.Ensembl);
	public static Query ebi = new Query("Query at EMBL-EBI",
			"http://www.ebi.ac.uk/ebisearch/search.ebi?db=allebi&query=%query%",null);

	public static Query google = new Query("Query at Google", "http://www.google.com/search?q=%query%",Icons.GOOGLE);

	public static Query plaza = new Query("Query in Plaza",
			"http://bioinformatics.psb.ugent.be/plaza/genes/view/%query%",Icons.PLAZA);

	private static final long serialVersionUID = 5252902483799067615L;
	private String queryURL;

	private String label;
	private Icon icon;

	
	public Query(String label, String queryURL,Icon icon) {
		// super(label);
		this.label = label;
		this.queryURL = queryURL;
		this.icon=icon;
	}

	public Icon getIcon(){
		return icon;
	}
	public String getLabel(){
		return label;
	}
	
	public void query(String q) {
		try {
			String query = queryURL.replaceAll("%query%", URLEncoder.encode(q.trim(), "UTF-8"));
			StaticUtils.browse(URIFactory.uri(query));
		} catch (IOException f) {
			// TODO Auto-generated catch block
			f.printStackTrace();
		} catch (URISyntaxException g) {
			// TODO Auto-generated catch block
			g.printStackTrace();
		}

	}

	@Override
	public String toString() {
		return label;
	}

}