/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.gui.menu.file;

import java.awt.event.ActionEvent;
import java.io.File;
import java.io.PrintWriter;
import java.util.logging.Level;

import javax.swing.AbstractAction;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;

import net.sf.genomeview.core.Configuration;
import net.sf.genomeview.data.Model;
import net.sf.genomeview.data.Session;
import net.sf.genomeview.gui.CrashHandler;
import net.sf.jannot.source.DataSource;
import net.sf.jannot.source.FileSource;
import net.sf.jannot.source.Locator;
import net.sf.jannot.source.URLSource;
/**
 * Action that takes care of saving all loaded data into a session file.
 * 
 * @author Thomas Abeel
 *
 */
public class SaveSessionAction extends AbstractAction {

	
	private static final long serialVersionUID = 1634805658386414327L;
	private Model model;

	public SaveSessionAction(Model model) {
		super("Save session");
		this.model = model;
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		JFileChooser chooser = new JFileChooser(Configuration.getFile("lastDirectory"));
		chooser.setMultiSelectionEnabled(false);
		chooser.setFileFilter(new FileFilter() {

			@Override
			public boolean accept(File f) {
				return f.getName().endsWith(".gvs")||f.isDirectory();
			}

			@Override
			public String getDescription() {
				return "GenomeView sessions";
			}

		});
		
		int result = chooser.showSaveDialog(model.getGUIManager().getParent());

		if (result == JFileChooser.APPROVE_OPTION) {
			try {
				File f=chooser.getSelectedFile();
				if(!f.getName().endsWith(".gvs")){
					f=new File(f+".gvs");
				}
				
				Session.save(f,model);
				
				Configuration.set("lastDirectory", f.getParentFile());
				
			} catch (Exception ex) {
				CrashHandler.crash(Level.SEVERE, "Could not save session", ex);
			}
		}

	}

}
