/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.gui.menu.selection;

import java.awt.event.ActionEvent;
import java.util.Observable;
import java.util.Observer;
import java.util.Set;

import net.sf.genomeview.data.Model;
import net.sf.genomeview.gui.menu.AbstractModelAction;
import net.sf.jannot.Location;

public class ZoomToSelectedLocationAction extends AbstractModelAction implements Observer {

    /**
     * 
     */
    private static final long serialVersionUID = 8764835346246357318L;

    public ZoomToSelectedLocationAction(Model model) {
        super("Zoom to location selection", model);
    }

    public void actionPerformed(ActionEvent e) {
        Set<Location> selected = model.selectionModel().getLocationSelection();
        int min = Integer.MAX_VALUE;
        int max = 0;
        for (Location f : selected) {
            if (min > f.start())
                min = f.start();
            if (max < f.end())
                max = f.end();

        }
        double margin = (max - min) * 0.05;
        model.vlm.setAnnotationLocationVisible(new Location((int) (min - margin), (int) (max + margin)));

    }

    public void update(Observable o, Object arg) {
        setEnabled(model.selectionModel().getFeatureSelection().size() > 0);

    }
}
