/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.gui.viztracks.hts;

import java.awt.Color;
import java.awt.event.MouseEvent;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JWindow;
import javax.swing.border.Border;

/**
 * 
 * @author Thomas Abeel
 * 
 */
class PileupTooltip extends JWindow {

	private static final long serialVersionUID = -7416732151483650659L;

	private JLabel floater = new JLabel();

	private PileupTrackConfig track;

	public PileupTooltip(PileupTrackConfig ptm) {
		this.track = ptm;

		floater.setBackground(Color.GRAY);
		floater.setForeground(Color.BLACK);
		Border emptyBorder = BorderFactory.createEmptyBorder(5, 5, 5, 5);
		Border colorBorder = BorderFactory.createLineBorder(Color.BLACK);
		floater.setBorder(BorderFactory.createCompoundBorder(colorBorder, emptyBorder));
		add(floater);
		pack();
	}

	public void set(MouseEvent e) {
		
		VizBuffer vb= track.getVizBuffer();
		String text = vb.getTooltip(e.getX());
		if(text==null){
			setVisible(false);
			return;
		}
		if (text!=null&&!text.toString().equals(floater.getText())) {
			floater.setText(text.toString());
			this.pack();
		}
		setLocation(e.getXOnScreen() + 5, e.getYOnScreen() + 5);

		if (!isVisible()) {
			setVisible(true);
		}
	}
}
